==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/StyleShapeEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StyleShapeEventArgsDescription } from "./StyleShapeEventArgsDescription";
/**
 * @hidden
 */
var StyleShapeEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(StyleShapeEventArgsDescriptionMetadata, _super);
    function StyleShapeEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    StyleShapeEventArgsDescriptionMetadata.b = function (a) {
        if (StyleShapeEventArgsDescriptionMetadata.a == null) {
            StyleShapeEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            StyleShapeEventArgsDescriptionMetadata.c(StyleShapeEventArgsDescriptionMetadata.a);
        }
        if (a.g(StyleShapeEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(StyleShapeEventArgsDescriptionMetadata.a);
    };
    StyleShapeEventArgsDescriptionMetadata.c = function (a) {
        a.item("ItemRef", "(w:Item,wf:Item)DataRef");
        a.item("ShapeFill", "(w:ShapeStyle.Fill,wf:ShapeFill)String");
        a.item("ShapeStroke", "(w:ShapeStyle.Stroke,wf:ShapeStroke)String");
        a.item("ShapeStrokeThickness", "(w:ShapeStyle.StrokeThickness,wf:ShapeStrokeThickness)Number:double");
        a.item("ShapeOpacity", "(w:ShapeStyle.Opacity,wf:ShapeOpacity)Number:double");
    };
    StyleShapeEventArgsDescriptionMetadata.d = function (a) {
        StyleShapeEventArgsDescriptionMetadata.b(a);
        a.u("StyleShapeEventArgs", function () { return new StyleShapeEventArgsDescription(); });
        a.t("StyleShapeEventArgs", StyleShapeEventArgsDescriptionMetadata.a);
    };
    StyleShapeEventArgsDescriptionMetadata.$t = markType(StyleShapeEventArgsDescriptionMetadata, 'StyleShapeEventArgsDescriptionMetadata');
    StyleShapeEventArgsDescriptionMetadata.a = null;
    return StyleShapeEventArgsDescriptionMetadata;
}(Base));
export { StyleShapeEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/StyleShapeEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StyleShapeEventArgsDescription } from "./StyleShapeEventArgsDescription";
/**
 * @hidden
 */
var StyleShapeEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(StyleShapeEventArgsDescriptionMetadata, _super);
    function StyleShapeEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    StyleShapeEventArgsDescriptionMetadata.b = function (a) {
        if (StyleShapeEventArgsDescriptionMetadata.a == null) {
            StyleShapeEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            StyleShapeEventArgsDescriptionMetadata.c(StyleShapeEventArgsDescriptionMetadata.a);
        }
        if (a.j(StyleShapeEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(StyleShapeEventArgsDescriptionMetadata.a);
    };
    StyleShapeEventArgsDescriptionMetadata.c = function (a) {
        a.item("ItemRef", "(w:Item,wf:Item)DataRef");
        a.item("ShapeFill", "(w:ShapeStyle.Fill,wf:ShapeFill)String");
        a.item("ShapeStroke", "(w:ShapeStyle.Stroke,wf:ShapeStroke)String");
        a.item("ShapeStrokeThickness", "(w:ShapeStyle.StrokeThickness,wf:ShapeStrokeThickness)Number:double");
        a.item("ShapeOpacity", "(w:ShapeStyle.Opacity,wf:ShapeOpacity)Number:double");
    };
    StyleShapeEventArgsDescriptionMetadata.d = function (a) {
        StyleShapeEventArgsDescriptionMetadata.b(a);
        a.aa("StyleShapeEventArgs", function () { return new StyleShapeEventArgsDescription(); });
        a.z("StyleShapeEventArgs", StyleShapeEventArgsDescriptionMetadata.a);
    };
    StyleShapeEventArgsDescriptionMetadata.$t = markType(StyleShapeEventArgsDescriptionMetadata, 'StyleShapeEventArgsDescriptionMetadata');
    StyleShapeEventArgsDescriptionMetadata.a = null;
    return StyleShapeEventArgsDescriptionMetadata;
}(Base));
export { StyleShapeEventArgsDescriptionMetadata };
